Crate peace_cfg

Crate peace_cfg 

Configuration model for the peace automation library.

This crate defines the API for logic and data to be used in the peace framework.

Re-exports

pub use crate::state::State;

Modules

accessors
id_newtype
Implements logic for a Cow<'static, str> newtype where only [A-Za-z0-9_] are valid characters.
peace_fmt
Presentation and formatting support for the peace automation framework.
state

Macros

app_name
Returns a const AppName validated at compile time.
id_newtype
Implements common behaviour for an ID type.
profile
Returns a const Profile validated at compile time.

Structs

AppName
Name of the application that is run by end users.
AppNameInvalidFmt
Error indicating AppName provided is not in the correct format.
FnCtx
References to pass information between the Peace framework and an item.

Enums

ApplyCheck
Whether the apply function needs to be executed.

Traits

Item
Defines all of the data and logic to manage an item.

Attribute Macros

async_trait