Configuration model for the peace automation library.
This crate defines the API for logic and data to be used in the peace
framework.
Re-exports
pub use crate::state::State;
Modules
- accessors
- id_
newtype - Implements logic for a
Cow<'static, str>newtype where only[A-Za-z0-9_]are valid characters. - peace_
fmt - Presentation and formatting support for the peace automation framework.
- state
Macros
- app_
name - Returns a
const AppNamevalidated at compile time. - id_
newtype - Implements common behaviour for an ID type.
- profile
- Returns a
const Profilevalidated at compile time.
Structs
- AppName
- Name of the application that is run by end users.
- AppName
Invalid Fmt - Error indicating
AppNameprovided is not in the correct format. - FnCtx
- References to pass information between the Peace framework and an item.
Enums
- Apply
Check - Whether the
applyfunction needs to be executed.
Traits
- Item
- Defines all of the data and logic to manage an item.